@@ -318,7 +318,8 @@ void AbstractAccount::setAccessToken(const QString &token)
     m_token = token;
     s_messageFilter->insert(m_token, QStringLiteral("ACCESS_TOKEN"));
     AccountManager::instance().addAccount(this, false);
-    AccountManager::instance().selectAccount(this, true);
+    // Future programmer: make sure not to set explicitUserAction here because it needs the settingsGroupName() to be valid first
+    AccountManager::instance().selectAccount(this, false);
     validateToken(true);
 }
 
@@ -739,7 +740,7 @@ void AbstractAccount::addNote(Identity *identity, const QString &note)
 
 void AbstractAccount::mutateRemotePost(const QString &url, const QString &verb)
 {
-    NetworkController::instance().requestRemoteObject(this, url, [=](QNetworkReply *reply) {
+    requestRemoteObject(QUrl(url), this, [=](QNetworkReply *reply) {
         const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
         const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
         const auto accounts = searchResult[QStringLiteral("accounts")].toArray();
