@@ -4,11 +4,13 @@
 
 #pragma once
 
-#include "abstractaccount.h"
-#include "abstracttimelinemodel.h"
+#include "account/abstractaccount.h"
+#include "timeline/abstracttimelinemodel.h"
 
-/// Model building on top of AbstractTimelineModel, used by MainTimelineModel and ThreadModel for example
-/// \see AbstractTimelineModel
+/**
+ * @brief Model building on top of AbstractTimelineModel, used by MainTimelineModel and ThreadModel for example.
+ * @see AbstractTimelineModel
+ */
 class TimelineModel : public AbstractTimelineModel
 {
     Q_OBJECT
@@ -24,48 +26,74 @@ public:
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
 
-    /// Start filling the timeline starting at \p fromId
+    /**
+     * @brief Start filling the timeline starting at @p fromId
+     */
     virtual void fillTimeline(const QString &fromId = {}) = 0;
 
-    /// Get a translated label for the timeline (e.g. "Home")
+    /**
+     * @return A translated label for the timeline (e.g. "Home")
+     */
     virtual QString displayName() const = 0;
 
-    /// Handle an incoming streaming event
+    /**
+     * @brief Handle an incoming streaming event.
+     */
     virtual void handleEvent(AbstractAccount::StreamingEventType eventType, const QByteArray &payload);
 
-    /// Initialize and start filling the timeline
+    /**
+     * @brief Initialize and start filling the timeline.
+     */
     void init();
 
     void setShouldLoadMore(bool shouldLoadMore);
 
 public Q_SLOTS:
-    /// Reply to the post at \p index
-    /// \see wantReply
+    /**
+     * @brief Reply to the post at @p index.
+     * @see wantReply()
+     */
     void actionReply(const QModelIndex &index);
 
-    /// Favorite the post at \p index
+    /**
+     * @brief Favorite the post at @p index.
+     */
     void actionFavorite(const QModelIndex &index);
 
-    /// Boost the post at \p index
+    /**
+     * @brief Boost the post at @p index.
+     */
     void actionRepeat(const QModelIndex &index);
 
-    /// Vote on the post at \p index
+    /**
+     * @brief Vote on the post at @p index.
+     */
     void actionVote(const QModelIndex &index, const QList<int> &choices);
 
-    /// Bookmark the post at \p index
+    /**
+     * @brief Bookmark the post at @p index.
+     */
     void actionBookmark(const QModelIndex &index);
 
-    /// Delete & re-draft the post at \p index
-    /// \see postSourceReady
+    /**
+     * @brief Delete & re-draft the post at @p index.
+     * @see postSourceReady()
+     */
     void actionRedraft(const QModelIndex &index, bool isEdit);
 
-    /// Delete the post at \p index
+    /**
+     * @brief Delete the post at @p index.
+     */
     void actionDelete(const QModelIndex &index);
 
-    /// Pin the post at \p index
+    /**
+     * @brief Pin the post at @p index.
+     */
     void actionPin(const QModelIndex &index);
 
-    /// Reset the timeline posts, and any additional state
+    /**
+     * @brief Reset the timeline posts, and any additional state.
+     */
     virtual void reset() = 0;
 
 Q_SIGNALS:
