@@ -6,6 +6,8 @@
 #include <KSharedConfig>
 #include <KWindowConfig>
 
+#include <QQuickWindow>
+
 void WindowController::setWindow(QQuickWindow *window)
 {
     Q_ASSERT(window != nullptr);
@@ -15,7 +17,7 @@ void WindowController::setWindow(QQuickWindow *window)
 void WindowController::restoreGeometry()
 {
     auto stateConfig = KSharedConfig::openStateConfig();
-    auto windowGroup = stateConfig->group(QStringLiteral("Window"));
+    const auto windowGroup = stateConfig->group(QStringLiteral("Window"));
 
     KWindowConfig::restoreWindowPosition(m_window, windowGroup);
     KWindowConfig::restoreWindowSize(m_window, windowGroup);
